==> react-lds-8.7.0.tgz: package/es/components/Badge/Badge.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { THEMES, getThemeClass } from '../../utils';
import { applyDecorators, decoratorProp } from '../../utils';

var Badge = function Badge(props) {
  var children = props.children,
      className = props.className,
      flavor = props.flavor,
      theme = props.theme,
      title = props.title,
      rest = _objectWithoutProperties(props, ["children", "className", "flavor", "theme", "title"]);

  var sldsClasses = ['slds-badge'].concat(_toConsumableArray(getThemeClass(theme)), [applyDecorators(flavor, 'badge'), className]);
  return React.createElement("span", _extends({}, rest, {
    className: cx(sldsClasses),
    title: title
  }), children, title && React.createElement("span", {
    className: "slds-assistive-text"
  }, title));
};

Badge.defaultProps = {
  className: null,
  flavor: null,
  theme: null,
  title: null
};
Badge.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Either a string or a string & an icon */
  children: PropTypes.node.isRequired,

  /** (optional) className */
  className: PropTypes.string,

  /**
   * Badge flavor: array of flavors, you can also provide a single flavor string.
   * Flavors: inverse, lightest
  */
  flavor: decoratorProp(['inverse', 'lightest']),

  /** DEPRECTATED: SLDS Theme */
  theme: PropTypes.oneOf(THEMES),

  /** Optional title that will be rendered as assistive-text */
  title: PropTypes.string
} : {};
export default Badge;

==> react-lds-9.1.0.tgz: package/es/components/Badge/Badge.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { THEMES, getThemeClass } from '../../utils';
import { applyDecorators, decoratorProp } from '../../utils';

var Badge = function Badge(props) {
  var children = props.children,
      className = props.className,
      flavor = props.flavor,
      theme = props.theme,
      title = props.title,
      rest = _objectWithoutProperties(props, ["children", "className", "flavor", "theme", "title"]);

  var sldsClasses = ['slds-badge'].concat(_toConsumableArray(getThemeClass(theme)), [applyDecorators(flavor, 'badge'), className]);
  return React.createElement("span", _extends({}, rest, {
    className: cx(sldsClasses),
    title: title
  }), children, title && React.createElement("span", {
    className: "slds-assistive-text"
  }, title));
};

Badge.defaultProps = {
  className: null,
  flavor: null,
  theme: null,
  title: null
};
Badge.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Either a string or a string & an icon */
  children: PropTypes.node.isRequired,

  /** (optional) className */
  className: PropTypes.string,

  /**
   * Badge flavor: array of flavors, you can also provide a single flavor string.
   * Flavors: inverse, lightest
  */
  flavor: decoratorProp(['inverse', 'lightest']),

  /** DEPRECTATED: SLDS Theme */
  theme: PropTypes.oneOf(THEMES),

  /** Optional title that will be rendered as assistive-text */
  title: PropTypes.string
} : {};
export default Badge;
